$fn=100;

include<openrail.scad>; //Note: bottom of rail is 2.4 behind/below
include<bearingmod.scad>; // modded to add other models (625, 6000), and local include
include<motorsmod.scad>; // modded for local include
include<Extruder/QXZExtruder.scad>;
//include<QXZlogo.scad>; // the logo

xposition=100; // Maximum x-travel is 200mm - Default is 100 (to set at center)
yposition=100; // Maximum y-travel is 186mm - Default is 186 (to set at rear of bed)
zposition=100; // Maximum z-travel is 200mm - Default is 100 (to set at center)

module v625zz(){ //5x16x5
  difference(){
    bearing(model=625);
    rotate_extrude() //v-groove
    polygon([[7.5,2.5],[8.1,1.29],[8.1,3.81]]);
  }
}

module v623zz(){ // 3x10x4
  difference(){
    bearing(model=623);
    rotate_extrude() // v-groove 0.5 deep
    polygon([[4.5,2.0],[5.1,1.2],[5.1,2.8]]);
  }
}

module 623v(){ // 3x12x4 1.2mm depth
  difference(){
    bearing(model=62312);
    rotate_extrude() // v-groove 1.2 deep
    polygon([[4.8,2.0],[6.1,0.6],[6.1,3.4]]);
  }
}

module 623uu(){ // 3x10x3 1mm depth
  difference(){
    bearing(model=62303);
    rotate_extrude() // v-groove 1mm deep
    polygon([[4.0,1.5],[5.1,0.9],[5.1,2.1]]);
  }
}

module 608zz(){ // 8x22x7
  bearing(model=608);
}

module 6000z(){ // 10x26x8
  bearing(model=6000);
}

module 693zz(){ // 3x8x4
  bearing(model=693);
}

module mr63zz(){ // 3x6x2.5
  bearing(model=63);
}

// This is spacer for 5M and larger id
module spacer(height=3,id=5){
    difference(){
        cylinder(h=height, r=id/2+2.5); //wall thickness is 2.5mm
        translate([0,0,-1])
        cylinder(h=height+2, r=(id+0.1)/2);
    }
}

// This is spacer for 3M id
module spacer3(height=1,id=3){
    difference(){
        cylinder(h=height, r=id/2+1.5); //wall thickness is 1mm
        translate([0,0,-1])
        cylinder(h=height+2, r=(id+0.1)/2);
    }
}

module miniwheel(){  // Note: Centered
   color("Black")
   difference(){
     union(){
        cylinder(h=5.78, r=15.23/2, center=true);
        // outer cone sections
        translate([0,0,-1.51-5.78/2])
        cylinder(h=1.51, r1=12.21/2, r2=15.23/2); 
        translate([0,0,5.78/2])
        cylinder(h=1.51, r1=15.23/2, r2=12.21/2);  
   }
   translate([0,0,0])
   cylinder(h=10.8, r=5.1/2, center=true);
}
}

module vwheel(){  // Note: Centered
   color("Black")
   difference(){
     union(){
        cylinder(h=5.78, r=24.39/2, center=true);
        // outer cone sections
        translate([0,0,-2.225-5.78/2])
        cylinder(h=2.225, r1=19.94/2, r2=24.39/2); 
        translate([0,0,5.78/2])
        cylinder(h=2.225, r1=24.39/2, r2=19.94/2);  
   }
   translate([0,0,0])
   cylinder(h=12.23, r=5.1/2, center=true);
}
}

module backzplate(){
color("Gainsboro")
difference(){
hull(){
  translate([-8,-8,0])
  cube([8,56,3]);
  cylinder(h=3,r=8);
  translate([0,40,0])
  cylinder(h=3,r=8);
}
translate([0,0,-1])
cylinder(h=5,r=2.55);
translate([0,20,-1])
cylinder(h=5,r=2.55);
translate([0,40,-1])
cylinder(h=5,r=2.55);
}
}

module zplate(){
color("Gainsboro")
difference(){
hull(){
minkowski(){
  cube([40.6,40,1.5]);
  cylinder(h=1.5,r=8);
}
translate([48.6,10,0])
  cube([24.4,20,3]);
}
translate([0,0,-1])
  cylinder(h=5,r=7.1/2);
translate([0,40,-1])
  cylinder(h=5,r=7.1/2);
translate([40.6,0,-1])
  cylinder(h=5,r=5.1/2);
translate([40.6,40,-1])
  cylinder(h=5,r=5.1/2);

translate([64,20,-1])
  cylinder(h=5,r=5.1/2);
translate([44,20,-1])
  cylinder(h=5,r=5.1/2);
}
}

module zplatespacer(){  // This will be a printed part
  difference(){
    cube([38,20,9.6]);
    translate([-1,10,18.2])
    rotate([0,90,0])
    vslot(40);
    translate([9,10,-1])
    cylinder(h=11.6,r=2.55);
    translate([29,10,-1])
    cylinder(h=11.6,r=2.55);
  }
}

module xplate(){
color("Gainsboro")
difference(){
 minkowski(){
   cube([42,40,1.5]); // y-size of openbuilds plate (for mini wheels) is 31.9
   cylinder(h=1.5,r=4);
} 
// mini-wheel holes
translate([11,4,-1])
  cylinder(h=5,r=7.1/2);
translate([31,4,-1])
  cylinder(h=5,r=7.1/2);
translate([11,36,-1])
  cylinder(h=5,r=5.1/2);
translate([31,36,-1])
  cylinder(h=5,r=5.1/2);

// string bolt holes
translate([0,5,-1])
  cylinder(h=5,r=4.1/2);
translate([42,5,-1])
  cylinder(h=5,r=4.1/2);
translate([0,35,-1])
  cylinder(h=5,r=4.1/2);
translate([42,35,-1])
  cylinder(h=5,r=4.1/2);

// nutsert holes
translate([1,20,-1])
  cylinder(h=5,r=5.1/2);
translate([10.5,20,-1])
  cylinder(h=5,r=5.1/2);
translate([31.5,20,-1])
  cylinder(h=5,r=5.1/2);
translate([41,20,-1])
  cylinder(h=5,r=5.1/2);
}
}

// this is hot end holder - to be printed
module heholder(){
difference(){
union(){
  hull(){ // back "half"
  translate([-25,-15.6,0])
  cube([50,9.5,12.5]);
  translate([-15,-6.2,0]) // 0.1 overlap
  cube([30,6,12.5]); // -0.2 "behind" xaxis
  }
  hull(){ // front "half"
  translate([-15,-1,0])
  cube([30,6,12.5]);
  translate([0,0,0])
  cylinder(h=12.5, r=12);
  }
}
  // e3d v6 barrel hole
  translate([0,0,-0.1])
  cylinder(h=12.7, r=6.1);
  translate([0,0,-0.1])
  cylinder(h=3.15, r=8.1);
  translate([0,0,8.95])
  cylinder(h=3.8, r=8.1);

  // outer nutsert indents
  translate([20,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=6.05, r=5.1/2);
  translate([-20,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=6.05, r=5.1/2);
  // outer 3mm holes
  translate([20,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=15.05, r=3.1/2);
  translate([-20,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=15.05, r=3.1/2);
  // outer socket indents
  translate([20,-5.1,6.25])
  rotate([-90,0,0])
  cylinder(h=4, r=5.6/2);
  translate([-20,-5.1,6.25])
  rotate([-90,0,0])
  cylinder(h=4, r=5.6/2);

  // inner nutsert indents
  translate([10.5,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=6.05, r=5.1/2);
  translate([-10.5,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=6.05, r=5.1/2);
  // inner 3mm holes
  translate([10.5,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=26.05, r=3.1/2);
  translate([-10.5,-15.65,6.25])
  rotate([-90,0,0])
  cylinder(h=26.05, r=3.1/2);
  // inner socket indents
  translate([10.5,5.7,6.25])
  rotate([-90,0,0])
  cylinder(h=4, r=5.6/2);
  translate([-10.5,5.7,6.25])
  rotate([-90,0,0])
  cylinder(h=4, r=5.6/2);

  // slicing plane - 0.2 thick (Note: maybe make 0.4 thick if too loose)
  translate([-16,-0.2,-0.1])
  cube([32,0.2,12.7]);
}
}


module yplate(){
color("Gainsboro")
difference(){
 minkowski(){
 cube([209,209,1.5]);
 cylinder(h=1.5,r=5);
 }
 translate([0,0,-1])
   cylinder(h=5,r=1.7);
 translate([0,0,1.34])
   cylinder(h=2.66,r1=1.7,r2=3.04);
 
 translate([209,0,-1])
   cylinder(h=5,r=1.7);
 translate([209,0,1.34])
   cylinder(h=2.66,r1=1.7,r2=3.04);

 translate([0,209,-1])
   cylinder(h=5,r=1.7);
 translate([0,209,1.34])
   cylinder(h=2.66,r1=1.7,r2=3.04);

 translate([209,209,-1])
   cylinder(h=5,r=1.7);
 translate([209,209,1.34])
   cylinder(h=2.66,r1=1.7,r2=3.04);
 
 translate([52,-6,-1])
   cube([105,12.5,5]);
}
}

module e3dv6(){
  import("e3dv6.stl");  // file must be local
}

module spool(){ // mid point is 14mm from base
color("Gainsboro")
rotate_extrude()
  polygon([[2.55,0],[2.55,25.5],[11,25.5],[11,24.5],[9,22.5],[9,5.5],[11,3.5],[11,0]]);
}

module spectra(length=10,color="Blue"){ // 100lb test: diameter=0.46
  color(color)
  cylinder(h=length,r=0.23);
}

// various testing
// cube for determining wall distance
//translate([110,20,-75.5])
//%cube([20,20,30]);

// This is the back board that everything is attached to.
module backplate(){
translate([0,20,-105]) // "front" is 20 from origin
rotate([90,0,0])
difference(){
  union(){
  translate([-220,0,0])
    cube([440,400,10]);
  // top tabs
  translate([-9+5*36,399,0])
    cube([18,11,10]);
  translate([-9-5*36,399,0])
    cube([18,11,10]);
  // side tabs
  translate([-230,0,0])
    cube([11,11,10]);
  translate([219,0,0])
    cube([11,11,10]);
  translate([-230,11+0*18+1*54,0])
    cube([11,18,10]);
  translate([219,11+0*18+1*54,0])
    cube([11,18,10]);
  translate([-230,11+1*18+2*54,0])
    cube([11,18,10]);
  translate([219,11+1*18+2*54,0])
    cube([11,18,10]);
  translate([-230,11+2*18+3*54,0])
    cube([11,18,10]);
  translate([219,11+2*18+3*54,0])
    cube([11,18,10]);
  translate([-230,11+3*18+4*54,0])
    cube([11,18,10]);
  translate([219,11+3*18+4*54,0])
    cube([11,18,10]);
  translate([-230,11+4*18+5*54,0])
    cube([11,18,10]);
  translate([219,11+4*18+5*54,0])
    cube([11,18,10]);
  }
  translate([-134,64,-1])
  minkowski(){
    cylinder(h=6,r=10);
    cube([268,291,6]);
  }
  // cutout for v-slot rail
  translate([-64,36,-1]) // 36 "up" from bottom
    cube([128,20,12]);
  // holes for corner brackets
  translate([-10,26,-1])
    cylinder(h=12,r=5.1/2);
  translate([10,26,-1])
    cylinder(h=12,r=5.1/2);
  // holes for fixed y pulley brackets
  translate([104,48,-1])
    cylinder(h=12,r=4.1/2);
  translate([124,48,-1])
    cylinder(h=12,r=4.1/2);
  translate([114,40,-1])
    cylinder(h=12,r=4.1/2);
  translate([-104,48,-1])
    cylinder(h=12,r=4.1/2);
  translate([-124,48,-1])
    cylinder(h=12,r=4.1/2);
  translate([-114,40,-1])
    cylinder(h=12,r=4.1/2);
}
}

// This is the plate that supports the ends of the y-rail (make 2)
module faceplate(){
difference(){
  cube([460,10,54]);  // NOTE: was 446 with 6mm and dado
  // cutout for v-slot rail
  translate([460/2-64,-1,36]) // 36 up from bottom
    cube([128,12,21]);
  // cutouts for tabs
  translate([-1,-1,18])
    cube([11,12,18]);
  translate([450,-1,18])
    cube([11,12,18]);
  // servo screw holes
  translate([5,11,9])
  rotate([90,0,0])
    cylinder(h=12,r=2.1/2);
  translate([5,11,54-9])
  rotate([90,0,0])
    cylinder(h=12,r=2.1/2);
  translate([460-5,11,9])
  rotate([90,0,0])
    cylinder(h=12,r=2.1/2);
  translate([460-5,11,54-9])
  rotate([90,0,0])
    cylinder(h=12,r=2.1/2);
  // holes for corner brackets
  translate([460/2-30,11,26])
  rotate([90,0,0])
    cylinder(h=12,r=5.1/2);
  translate([460/2+30,11,26])
  rotate([90,0,0])
    cylinder(h=12,r=5.1/2);
  // holes for name plate (decorative)
  translate([460/2-74,11,46])
  rotate([90,0,0])
    cylinder(h=12,r=5.1/2);
  translate([460/2+74,11,46])
  rotate([90,0,0])
    cylinder(h=12,r=5.1/2);
}
}

// This is the side plate blank (different holes drilled in each one)
module sideplate(){
  difference(){
  union(){
  hull(){
    translate([-5,0,0])
    cube([10,348,54]);
    translate([-5,116,0])
    cube([10,86,400]);
  }
  // top tab
  translate([-5,134,399])
    cube([10,50,11]);
  // bottom tabs
  translate([-5,-10,18])
    cube([10,11,18]);
  translate([-5,347,18])
    cube([10,11,18]);
  }
  // tab servo screw holes
  translate([-6,143,405]) // top (134+9)
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,143+32,405])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,-5,27]) // bottom
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,348+5,27])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  // vertical servo screw holes
  translate([-6,159,20])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+1*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+2*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+3*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+4*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+5*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+6*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+7*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+8*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+9*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  translate([-6,159,20+10*36])
  rotate([0,90,0])
  cylinder(h=12,r=2.1/2);
  // tab slots
  translate([-6,154,0])
  cube([12,10,11]);
  translate([-6,154,11+1*54])
  cube([12,10,18]);
  translate([-6,154,11+1*18+2*54])
  cube([12,10,18]);
  translate([-6,154,11+2*18+3*54])
  cube([12,10,18]);
  translate([-6,154,11+3*18+4*54])
  cube([12,10,18]);
  translate([-6,154,11+4*18+5*54])
  cube([12,10,18]);
  }
}

module topplate(){
  difference(){
    translate([-230,0,0])
    cube([460,86,10]);
    // cutout for feeding filament
    hull(){
      translate([-134,58,-1])
      cylinder(h=12,r=10);
      translate([134,58,-1])
      cylinder(h=12,r=10);
    }
    // cutout for end tabs
    translate([-231,18,-1])
      cube([11,50,12]);
    translate([220,18,-1])
      cube([11,50,12]);
    // tab slots
    translate([-9+5*36,38,-1])
      cube([18,10,12]);
    translate([-9-5*36,38,-1])
      cube([18,10,12]);
    // servo screw holes
    translate([-225,9,-1]) // ends
      cylinder(h=12,r=2.1/2);
    translate([-225,86-9,-1])
      cylinder(h=12,r=2.1/2);
    translate([225,9,-1])
      cylinder(h=12,r=2.1/2);
    translate([225,86-9,-1])
      cylinder(h=12,r=2.1/2);
    translate([18,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([18+1*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18-1*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([18+2*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18-2*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([18+3*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18-3*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([18+4*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18-4*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([18+5*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
    translate([-18-5*36,43,-1]) // centerline
      cylinder(h=12,r=2.1/2);
  }
}

// backplate with bolt holes
difference(){
color("Wheat")
backplate();
  
// bolt holes
// upper inner
translate([-154,21,275])
rotate([90,0,0])
cylinder(h=12,r=5.05);

translate([154,21,275])
rotate([90,0,0])
cylinder(h=12,r=5.05);

// lower inner
translate([-154,21,-25])
rotate([90,0,0])
cylinder(h=12,r=5.05);

translate([154,21,-25])
rotate([90,0,0])
cylinder(h=12,r=5.05);

// upper outer
translate([-192.8,21,275])
rotate([90,0,0])
cylinder(h=12,r=4.05);

translate([192.8,21,275])
rotate([90,0,0])
cylinder(h=12,r=4.05);

// lower outer
translate([-171.2,21,-54])
rotate([90,0,0])
cylinder(h=12,r=4.05);

translate([171.2,21,-54])
rotate([90,0,0])
cylinder(h=12,r=4.05);

// stepper and spools
translate([-194.8,21,-83])
rotate([90,0,0])
cylinder(h=12,r=12);
translate([-194.8-12,9,-106])
cube([24,12,23]);

translate([194.8,21,-83])
rotate([90,0,0])
cylinder(h=12,r=12);
translate([194.8-12,9,-106])
cube([24,12,23]);


// stepper screw holes
// left side
translate([-194.8-15.5,21,-83-15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([-194.8+15.5,21,-83-15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([-194.8-15.5,21,-83+15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([-194.8+15.5,21,-83+15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
// right side
translate([194.8-15.5,21,-83-15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([194.8+15.5,21,-83-15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([194.8-15.5,21,-83+15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);
translate([194.8+15.5,21,-83+15.5])
rotate([90,0,0])
cylinder(h=12,r=1.55);

// v-slot bolt holes
// left side
translate([-154,21,25])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([-154,21,75])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([-154,21,125])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([-154,21,175])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([-154,21,225])
rotate([90,0,0])
cylinder(h=12,r=2.55);
// right side
translate([154,21,25])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([154,21,75])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([154,21,125])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([154,21,175])
rotate([90,0,0])
cylinder(h=12,r=2.55);
translate([154,21,225])
rotate([90,0,0])
cylinder(h=12,r=2.55);

}

module vslot(length=1){
color("Gainsboro")
linear_extrude(length,convexity=12)
import("VSlot20x20.dxf"); // file must be local
} 

module vslot80(length=1){
color("Gainsboro")
linear_extrude(length,convexity=20)
import("vslot20x80.dxf"); // file must be local
}

// vertical rails
// Note: should be able to get full 200mm z-travel.  zplate is 56mm tall, but bearings
//   are mounted 8mm in and 40mm apart.  zplate traveling 3mm above and below rail
//   will leave 5mm of rail on each end before axle center reaches tip of rail.
//   This will give 250-56 = 194  plus 3+3 for 200mm travel. (see print bed plate)
translate([-154,0,0])
vslot(250);
translate([-164.4,-10-2.4,125]) // use 1/2 of .8 overlap
rail(250);
translate([-143.6,-10-2.4,125]) // use 1/2 of .8 overlap
rotate([0,0,180])
rail(250);
translate([154,0,0])
vslot(250);
translate([143.6,-10-2.4,125]) // use 1/2 of .8 overlap
rail(250);
translate([164.4,-10-2.4,125]) // use 1/2 of .8 overlap
rotate([0,0,180])
rail(250);

// print bed rail - vertical location 15 to 20mm clearance from hot end - adjust
translate([0,214,-59]) // Note: 59 down (center) leaves 36mm of board below
rotate([90,0,0])
vslot80(368);  // with right bed can probably get 250mm travel...

// "front" faceplate
color("Wheat")
translate([-460/2,204,-105])
faceplate();

/*/ "front" logo
color("silver")
translate([0,216,-69])
rotate([90,0,180])
difference(){
logofront();
translate([-64,-30,-7.5])
  cube([128,30,5]);
}
*/

// "rear" faceplate
color("Wheat")
translate([-460/2,-154,-105])
faceplate();


// "left" side plate (with stepper holes)
difference(){
color("Wheat")
translate([225,-144,-105])  // add >12 to x to explode
sideplate();
  // stepper center hole
  translate([219,42,246]) // 239 is centered with small screw hole
  rotate([0,90,0])
  cylinder(h=12,r=12);
  // stepper screw holes
  translate([219,42-15.5,246-15.5])
  rotate([0,90,0])
  cylinder(h=12,r=3.1/2);
  translate([219,42-15.5,246+15.5])
  rotate([0,90,0])
  cylinder(h=12,r=3.1/2);
  translate([219,42+15.5,246-15.5])
  rotate([0,90,0])
  cylinder(h=12,r=3.1/2);
  translate([219,42+15.5,246+15.5])
  rotate([0,90,0])
  cylinder(h=12,r=3.1/2);
}

// extruder stepper (on "left" side plate)
translate([220,42,246])
rotate([0,90,0])
stepper_motor_mount(17);


// "right" side plate
difference(){
color("Wheat")
translate([-225,-144,-105])  // subtract >12 from x to explode
sideplate();
  // pololu stepper mount plate holes (at tops of plate hole slots)
  translate([-231,42+6.35,-25-12.7])
  rotate([0,90,0])
  cylinder(h=12,r=4.1/2);
  translate([-231,42-6.35,-25-12.7])
  rotate([0,90,0])
  cylinder(h=12,r=4.1/2);
  translate([-231,42+15.9,-25-25.3])
  rotate([0,90,0])
  cylinder(h=12,r=4.1/2);
  translate([-231,42-15.9,-25-25.3])
  rotate([0,90,0])
  cylinder(h=12,r=4.1/2);
}

// y motor and spool (Note: mounted on plate attached to "ride" side plate)
translate([-194.8,42,-25])
rotate([180,0,0])
stepper_motor_mount(17); // 42.3mm square
translate([-194.8,42,-27]) // spool offset 2 from stepper face (z direction)
rotate([180,0,0])
spool();


// top plate with filament slot
color("Wheat")
translate([0,-28,295])  // add >12 to z to explode
topplate();

module printbed(){
// print bed build plate
color("DimGray")
translate([108,19.5,-47]) // Note: offset is from edge
rotate([0,0,90])
import("buildplate.stl");

// vwheels and spacers
translate([49.85,58.5,-59])
vwheel();
translate([49.85,58.5,-59+10.23/2])
spacer(7); // 6mm + 1mm precision spacer

translate([-49.85,58.5,-59])
vwheel();
translate([-49.85,58.5,-59+10.23/2])
spacer(7); // 6mm + 1mm precision spacer

translate([49.85,58.5+138,-59])
vwheel();
translate([49.85,58.5+138,-59+10.23/2])
spacer(7); // 6mm + 1mm precision spacer

translate([-49.85,58.5+138,-59])
vwheel();
translate([-49.85,58.5+138,-59+10.23/2])
spacer(7); // 6mm + 1mm precision spacer

// yplate is actual print bed
translate([-104.5,23,-34]) // Note: offset is from corner hole (3.5 more than plate)
yplate();

// y pulleys and spacers
translate([-104.5,23,-37])
spacer3(3);
translate([-104.5,23,-41])
623v();
translate([-104.5,23,-44])
spacer3(3);

translate([104.5,23,-37])
spacer3(3);
translate([104.5,23,-41])
623v();
translate([104.5,23,-44])
spacer3(3);

translate([-104.5,232,-37])
spacer3(3);
translate([-104.5,232,-41])
623v();
translate([-104.5,232,-44])
spacer3(3);

translate([104.5,232,-37])
spacer3(3);
translate([104.5,232,-41])
623v();
translate([104.5,232,-44])
spacer3(3);
} // end printbed

module ybracketright(){
// stationary y pulley bracket
difference(){
union(){
hull(){
translate([-124,25,-57])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([-104,25,-57])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([-114,25,-65])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([-120,41,-42])
rotate([90,0,0])
cylinder(h=21, r=2.5);
}
translate([-120,41,-36])
rotate([90,0,0])
cylinder(h=21, r=2.5);
hull(){
translate([-114,25,-43])
cylinder(h=8,r=3.5);
translate([-114,25,-45.5])
cylinder(h=2.5,r1=1.3,r2=3.5);
translate([-114,36,-43])
cylinder(h=8,r=3.5);
translate([-114,36,-45.5])
cylinder(h=2.5,r1=1.3,r2=3.5);
translate([-120,20,-43])
cube([5,1,9.5]);
translate([-120,40,-43])
cube([5,1,9.5]);
}
translate([-122.5,20,-42])
cube([3,3,6]);
translate([-122.5,38,-42])
cube([3,3,6]);
}
// bolt holes
translate([-124,26,-57])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
translate([-104,26,-57])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
translate([-114,26,-65])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
// flats for bolt heads
translate([-124,35,-57])
rotate([90,0,0])
cylinder(h=10,r=4);
translate([-104,35,-57])
rotate([90,0,0])
cylinder(h=10,r=4);
translate([-114,35,-65])
rotate([90,0,0])
cylinder(h=10,r=4);
// cutouts for pulleys
hull(){
translate([-114,25,-41])
cylinder(h=4,r=6);
translate([-114,36,-41])
cylinder(h=4,r=6);
}
// pulley bolt and head holes
translate([-114,25,-44])
cylinder(h=5,r=3.05/2); // bottom of hole for tapping
translate([-114,36,-44])
cylinder(h=5,r=3.05/2);
translate([-114,25,-38])
cylinder(h=5,r=3.1/2); // top of hole - untapped
translate([-114,36,-38])
cylinder(h=5,r=3.1/2);
translate([-114,25,-34.5])
cylinder(h=3,r=5.6/2); // bolt head indent
translate([-114,36,-34.5])
cylinder(h=3,r=5.6/2);
}
}

module ybracketleft(){
// stationary y pulley bracket
difference(){
union(){
hull(){
translate([124,25,-57])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([104,25,-57])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([114,25,-65])
rotate([90,0,0])
cylinder(h=5,r=4);
translate([120,41,-42])
rotate([90,0,0])
cylinder(h=21, r=2.5);
// tuning peg mount
translate([125,26,-52])
cylinder(h=10,r1=1,r2=6);
translate([122.5,20,-42])
cube([8.5,1,1]);
}
translate([120,41,-36])
rotate([90,0,0])
cylinder(h=21, r=2.5);
hull(){
translate([114,25,-43])
cylinder(h=8,r=3.5);
translate([114,25,-45.5])
cylinder(h=2.5,r1=1.3,r2=3.5);
translate([114,36,-43])
cylinder(h=8,r=3.5);
translate([114,36,-45.5])
cylinder(h=2.5,r1=1.3,r2=3.5);
translate([115,20,-43])
cube([5,1,9.5]);
translate([115,40,-43])
cube([5,1,9.5]);
}
translate([119.5,20,-42])
cube([3,3,6]);
translate([119.5,38,-42])
cube([3,3,6]);
}
// bolt holes
translate([124,26,-57])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
translate([104,26,-57])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
translate([114,26,-65])
rotate([90,0,0])
cylinder(h=7,r=4.1/2);
// flats for bolt heads
translate([124,35,-57])
rotate([90,0,0])
cylinder(h=10,r=4);
translate([104,35,-57])
rotate([90,0,0])
cylinder(h=10,r=4);
translate([114,35,-65])
rotate([90,0,0])
cylinder(h=10,r=4);
// cutouts for pulleys
hull(){
translate([114,25,-41])
cylinder(h=4,r=6);
translate([114,36,-41])
cylinder(h=4,r=6);
}
// pulley bolt and head holes
translate([114,25,-44])
cylinder(h=5,r=3.05/2); // bottom of hole for tapping
translate([114,36,-44])
cylinder(h=5,r=3.05/2);
translate([114,25,-38])
cylinder(h=5,r=3.1/2); // top of hole - untapped
translate([114,36,-38])
cylinder(h=5,r=3.1/2);
translate([114,25,-34.5])
cylinder(h=3,r=5.6/2); // bolt head indent
translate([114,36,-34.5])
cylinder(h=3,r=5.6/2);
// tuning peg hole and flat
translate([125.1,26,-52])
cylinder(h=11,r=5.05/2);
translate([122.5,19,-42])
cube([10,23,5]);
}
}


ybracketright();
ybracketleft();

// stationary y pulleys - Note: overlap with moving pulleys of 0.5mm - removed w/63zz
// Note: This is about the best I can do: 190mm y-travel w/693zz, 196mm w/63zz
translate([-114,25,-40.5])
623uu(); // 3 X 10 X 3
translate([-114,36,-40.5])
623uu();
translate([114,25,-40.5])
623uu();
translate([114,36,-40.5])
623uu();

module zgantry(){
// horizontal rail
translate([-139,0,125])
rotate([0,90,0])
vslot(278); // allows 201 x-travel

// gantry plates
translate([-174.3,-17.8,105]) // left zplate
rotate([90,0,0])
zplate();

translate([-139.3,-17.8,135]) // left zplate spacer
rotate([-90,0,0])
zplatespacer();

translate([174.3,-17.8,145]) // right zplate
rotate([90,180,0])
zplate();

translate([101.3,-17.8,135]) // right zplate spacer
rotate([-90,0,0])
zplatespacer();

translate([-133.7,13,105]) // left backzplate
rotate([90,0,0])
backzplate();

translate([133.7,10,105]) // right backzplate
rotate([-90,180,0])
backzplate();

// z carriage pulleys and spacers [maybe relocate this code?]
//133.7 is distance for perfect match (x-direction) [20.3 off center of extrusion]
translate([-133.7,-9.8,105]) // lower inside rail pulley
rotate([90,0,0])
v625zz();
translate([-133.7,-14.8,105]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([-133.7,-9.8,145]) // upper inside rail pulley
rotate([90,0,0])
v625zz();
translate([-133.7,-14.8,145]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([-174.3,-9.8,105])  // lower outside rail pulley
rotate([90,0,0])
v625zz();
translate([-174.3,-14.8,105]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([-174.3,-9.8,145]) // upper outside rail pulley
rotate([90,0,0])
v625zz();
translate([-174.3,-14.8,145]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([-133.7,2.4,105]) // lower inside drive pulley
rotate([90,0,0])
v625zz();
translate([-133.7,-2.7,105]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);
translate([-133.7,10,105]) // 7.5mm pulley spacer (before backzplate)
rotate([90,0,0])
spacer(7.5);

translate([-133.7,2.4,145])  // upper inside drive pulley
rotate([90,0,0])
v625zz();
translate([-133.7,-2.7,145]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);
translate([-133.7,10,145]) // 7.5mm pulley spacer (before backzplate)
rotate([90,0,0])
spacer(7.5);

translate([-174.3,2.4,105])  // lower outside drive pulley
rotate([90,0,0])
v625zz();
translate([-174.3,-2.7,105]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);

translate([-174.3,2.4,145])  //upper outside drive pulley
rotate([90,0,0])
v625zz();
translate([-174.3,-2.7,145]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);

translate([133.7,-9.8,105])
rotate([90,0,0])
v625zz();
translate([133.7,-14.8,105]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([133.7,-9.8,145])
rotate([90,0,0])
v625zz();
translate([133.7,-14.8,145]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([174.3,-9.8,105])
rotate([90,0,0])
v625zz();
translate([174.3,-14.8,105]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([174.3,-9.8,145])
rotate([90,0,0])
v625zz();
translate([174.3,-14.8,145]) // 3mm plate eccentric/spacer
rotate([90,0,0])
spacer();

translate([133.7,2.4,105])
rotate([90,0,0])
v625zz();
translate([133.7,-2.7,105]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);
translate([133.7,10,105]) // 7.5mm pulley spacer (before backzplate)
rotate([90,0,0])
spacer(7.5);

translate([133.7,2.4,145])
rotate([90,0,0])
v625zz();
translate([133.7,-2.7,145]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);
translate([133.7,10,145]) // 7.5mm pulley spacer (before backzplate)
rotate([90,0,0])
spacer(7.5);

translate([174.3,2.4,105])
rotate([90,0,0])
v625zz();
translate([174.3,-2.7,105]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);

translate([174.3,2.4,145])
rotate([90,0,0])
v625zz();
translate([174.3,-2.7,145]) // 7mm pulley spacer (6mm+precision shim)
rotate([90,0,0])
spacer(7);

// strings
translate([-133.7,0,112.5]) // horiz left lower
rotate([0,90,0])
spectra(133.7);

translate([-133.7,0,137.5]) // horiz left upper
rotate([0,90,0])
spectra(133.7,"Red");

translate([133.7,0,112.5]) // horiz right lower
rotate([0,-90,0])
spectra(133.7,"Red");

translate([133.7,0,137.5]) // horiz right upper
rotate([0,-90,0])
spectra(133.7);

} // end zgantry

// x carriage
module effector(){
translate([-21,14.4,105]) // xplate (Note: 1.4 clearance to v-slot)
rotate([90,0,0])
xplate();

translate([0,14.4+15.6,105+13.75]) // hot end holder
heholder();
  
// for extruder location, z=110 is center of travel
//   110-100  is bottom of travel, 110+100  is top of travel
translate([0,30,110])  // z=110 is center
rotate([90,0,90])
color("Silver")
e3dv6();

// mini v-wheels and spacers for x carriage
translate([-10,0,109])
rotate([90,0,0])
miniwheel();
translate([-10,4.4,109])
rotate([-90,0,0])
spacer(7);

translate([10,0,109])
rotate([90,0,0])
miniwheel();
translate([10,4.4,109])
rotate([-90,0,0])
spacer(7);

translate([-10,0,141])
rotate([90,0,0])
miniwheel();
translate([-10,4.4,141])
rotate([-90,0,0])
spacer(7);

translate([10,0,141])
rotate([90,0,0])
miniwheel();
translate([10,4.4,141])
rotate([-90,0,0])
spacer(7);
} // end effector

// board pulleys
// upper inner idlers
translate([-154,0,275])
rotate([90,0,0])
bearing(model=6000);
translate([-154,0,275])
rotate([-90,0,0])
bearing(model=6000); //10mm*26mm*8mm
translate([-154,10,275])
rotate([90,0,0])
spacer(2,10);

translate([154,0,275])
rotate([90,0,0])
bearing(model=6000);
translate([154,0,275])
rotate([-90,0,0])
bearing(model=6000);
translate([154,10,275])
rotate([90,0,0])
spacer(2,10);

// lower inner idlers
translate([-154,0,-25])
rotate([90,0,0])
bearing(model=6000);
translate([-154,0,-25])
rotate([-90,0,0])
bearing(model=6000);
translate([-154,10,-25])
rotate([90,0,0])
spacer(2,10);

translate([154,0,-25])
rotate([90,0,0])
bearing(model=6000);
translate([154,0,-25])
rotate([-90,0,0])
bearing(model=6000);
translate([154,10,-25])
rotate([90,0,0])
spacer(2,10);

// upper outer idlers
translate([-192.8,0,275])
rotate([90,0,0])
bearing(model=608);
translate([-192.8,0,275])
rotate([-90,0,0])
bearing(model=608); //8mm*22mm*7mm
translate([-192.8,10,275]) 
rotate([90,0,0])
spacer(3,8);

translate([192.8,0,275])
rotate([90,0,0])
bearing(model=608);
translate([192.8,0,275])
rotate([-90,0,0])
bearing(model=608); //8mm*22mm*7mm
translate([192.8,10,275]) 
rotate([90,0,0])
spacer(3,8);

// lower outer idlers
translate([-171.2,0,-54])
rotate([90,0,0])
bearing(model=608);
translate([-171.2,0,-54])
rotate([-90,0,0])
bearing(model=608); //8mm*22mm*7mm
translate([-171.2,10,-54]) 
rotate([90,0,0])
spacer(3,8);

translate([171.2,0,-54])
rotate([90,0,0])
bearing(model=608);
translate([171.2,0,-54])
rotate([-90,0,0])
bearing(model=608); //8mm*22mm*7mm
translate([171.2,10,-54]) 
rotate([90,0,0])
spacer(3,8);

// CoreXZ spools and motors
translate([-194.8,14,-83])
rotate([90,0,0])
spool(); //working diameter = 18mm
translate([-194.8,20,-83]) // spool offset 2 from stepper face (y direction)
rotate([90,0,0])
stepper_motor_mount(17);

translate([194.8,14,-83])
rotate([90,0,0])
spool(); //working diameter = 18mm
translate([194.8,20,-83])
rotate([90,0,0])
stepper_motor_mount(17);

//strings
translate([-194.8,0,-92]) // left spool across
rotate([0,85.8,0])
spectra(368,"Red");

translate([194.8,0,-92]) // right spool across
rotate([0,-85.8,0])
spectra(368);

translate([-203.8,0,-83])  // left outer
spectra(358,"Red");

translate([203.8,0,-83]) // right outer
spectra(358);

translate([-181.8,0,-54]) // left middle lower
spectra(159);

translate([-181.8,0,145]) // left middle upper
spectra(130,"Red");

translate([181.8,0,-54]) // right middle lower
spectra(159,"Red");

translate([181.8,0,145]) // right middle upper
spectra(130);

translate([-166.8,0,-25]) // left rail outer lower
spectra(130);

translate([-166.8,0,145]) // left rail outer upper
spectra(130,"Red");

translate([-141.2,0,-25]) // left rail inner lower
spectra(130);

translate([-141.2,0,145]) // left rail inner upper
spectra(130,"Red");

translate([166.8,0,-25]) // right rail outer lower
spectra(130,"Red");

translate([166.8,0,145]) // right rail outer upper
spectra(130);

translate([141.2,0,-25]) // right rail inner lower
spectra(130,"Red");

translate([141.2,0,145]) // right rail inner upper
spectra(130);


// All motion axes
translate([100-xposition,0,zposition-100]) // Max travel 200mm (home is 100)
effector();

translate([0,yposition-190,0]) // Max travel is 186, but use 190mm to adjust bed
printbed();

translate([0,0,zposition-100])
zgantry();

/*
translate([230,42,246])
rotate([90,0,90])
extruder();
*/
